{% extends "ui/catalog/base.html" %} {% load url from future %} {% load icons %} {% load bob %} {% block contentarea %}
{% block content %}

{% spaceless %} {% include 'ui/column-header.html' with label='Date' name='date' always=1 type='date' %} {% include 'ui/column-header.html' with label='User' name='user' always=1 %} {% include 'ui/column-header.html' with label='Group' name='group' always=1 %} {% include 'ui/column-header.html' with label='Model' name='model' always=1 %} {% include 'ui/column-header.html' with label='Field' name='field' always=1 %} {% include 'ui/column-header.html' with label='Old value' name='old' always=1 %} {% include 'ui/column-header.html' with label='New value' name='new' always=1 %} {% endspaceless %}
{% for h in items.object_list %}
{{ h.date|timesince_limited }} | {{ h.user|default:'' }} | {% spaceless %} {% if h.component_model_group %} {{ h.component_model_group.type|component_model_type_icon }} {{ h.component_model_group }} {% else %} {% if h.device_model_group %} {{ h.device_model_group.type|device_model_type_icon }} {{ h.device_model_group }} {% else %} Unassigned {% endif %} {% endif %} {% endspaceless %} | {% spaceless %} {% if h.component_model %} {{ h.component_model.type|component_model_type_icon }} {{ h.component_model }} {% endif %} {% if h.device_model %} {{ h.device_model.type|device_model_type_icon }} {{ h.device_model }} {% endif %} {% endspaceless %} | {{ h.field_name }} | {{ h.old_value }} | {{ h.new_value }}
{% endfor %}

{% pagination items fugue_icons=1 url_query=url_query show_all=1 %} {% endblock %} {% endblock %}